@@ -1,13 +1,16 @@
 """
 Methods for transforming Robot Framework ast model programmatically.
 """
-from typing import Optional
+from typing import Dict, List, Optional
 
 from robotidy import app, disablers, files, skip, transformers, utils
 from robotidy.config import Config, FormattingConfig
+from robotidy.transformers import TransformConfig, TransformConfigMap
 
 
 def get_skip_config(config):
+    # TODO: Improve it
+    skip_comments = config.get("skip_comments", False)
     skip_documentation = config.get("skip_documentation", False)
     skip_return_values = config.get("skip_return_values", False)
     skip_keyword_call = config.get("skip_keyword_call", [])
@@ -20,6 +23,8 @@ def get_skip_config(config):
     skip_timeout = config.get("skip_timeout", False)
     skip_return = config.get("skip_return", False)
     skip_tags = config.get("skip_tags", False)
+    skip_sections = config.get("skip_sections", "")
+    skip_block_comments = config.get("skip_block_comments", False)
     return skip.SkipConfig(
         documentation=skip_documentation,
         return_values=skip_return_values,
@@ -33,6 +38,9 @@ def get_skip_config(config):
         timeout=skip_timeout,
         return_statement=skip_return,
         tags=skip_tags,
+        comments=skip_comments,
+        block_comments=skip_block_comments,
+        sections=skip_sections,
     )
 
 
@@ -54,23 +62,39 @@ def get_formatting_config(config, kwargs):
 
 
 def get_robotidy(src: str, output: Optional[str], **kwargs):
+    def convert_transformers_config(
+        param_name: str,
+        config: Dict,
+        force_included: bool = False,
+        custom_transformer: bool = False,
+        is_config: bool = False,
+    ) -> List[TransformConfig]:
+        return [
+            TransformConfig(
+                tr, force_include=force_included, custom_transformer=custom_transformer, is_config=is_config
+            )
+            for tr in config.get(param_name, ())
+        ]
+
     # TODO Refactor - Config should be read in one place both for API and CLI
     # TODO Remove kwargs usage - other SDKs are not using this feature
     config = files.find_and_read_config((src,))
     config = {k: str(v) if not isinstance(v, (list, dict)) else v for k, v in config.items()}
-    converter = transformers.TransformType()
-    transformer_list = [converter.convert(tr, None, None) for tr in config.get("transform", ())]
-    configurations = [converter.convert(c, None, None) for c in config.get("configure", ())]
+    transformer_list = convert_transformers_config("transform", config, force_included=True)
+    custom_transformers = convert_transformers_config("load-transformers", config, custom_transformer=True)
+    configurations = convert_transformers_config("configure", config, is_config=True)
+    transformer_config = TransformConfigMap(transformer_list, custom_transformers, configurations)
     formatting_config = get_formatting_config(config, kwargs)
     exclude = config.get("exclude", None)
     extend_exclude = config.get("extend_exclude", None)
+    reruns = config.get("reruns", 0)
+    config_directory = config.get("config_directory", None)
     exclude = utils.validate_regex(exclude if exclude is not None else files.DEFAULT_EXCLUDES)
     extend_exclude = utils.validate_regex(extend_exclude)
     global_skip = get_skip_config(config)
     language = config.get("language", None)
     configuration = Config(
-        transformers=transformer_list,
-        transformers_config=configurations,
+        transformers_config=transformer_config,
         skip=global_skip,
         src=(),
         exclude=exclude,
@@ -86,6 +110,8 @@ def get_robotidy(src: str, output: Optional[str], **kwargs):
         target_version=utils.ROBOT_VERSION.major,
         color=False,
         language=language,
+        reruns=reruns,
+        config_directory=config_directory,
     )
     return app.Robotidy(config=configuration)
 
