@@ -44,6 +44,7 @@ class SkipConfig:
             "skip_tags",
             "skip_comments",
             "skip_block_comments",
+            "skip_sections",
         }
     )
 
@@ -63,6 +64,7 @@ class SkipConfig:
         tags: bool = False,
         comments: bool = False,
         block_comments: bool = False,
+        sections: str = "",
     ):
         self.documentation = documentation
         self.return_values = return_values
@@ -78,6 +80,7 @@ class SkipConfig:
         self.tags = tags
         self.comments = comments
         self.block_comments = block_comments
+        self.sections = parse_csv(sections)
 
     def update_with_str_config(self, **kwargs):
         for name, value in kwargs.items():
@@ -105,6 +108,7 @@ class Skip:
         self.keyword_call_pattern = {validate_regex(pattern) for pattern in skip_config.keyword_call_pattern}
         self.any_keword_call = self.check_any_keyword_call()
         self.skip_settings = self.parse_skip_settings(skip_config)
+        self.skip_sections = set(skip_config.sections)
 
     @staticmethod
     def parse_skip_settings(skip_config):
@@ -143,22 +147,14 @@ class Skip:
             return False
         return comment.tokens and comment.tokens[0].type == Token.COMMENT
 
+    def section(self, name):
+        return name in self.skip_sections
 
-documentation_option = click.option(
-    "--skip-documentation",
-    is_flag=True,
-    help="Skip formatting of documentation",
-)
-return_values_option = click.option(
-    "--skip-return-values",
-    is_flag=True,
-    help="Skip formatting of return values",
-)
+
+documentation_option = click.option("--skip-documentation", is_flag=True, help="Skip formatting of documentation")
+return_values_option = click.option("--skip-return-values", is_flag=True, help="Skip formatting of return values")
 keyword_call_option = click.option(
-    "--skip-keyword-call",
-    type=str,
-    multiple=True,
-    help="Keyword call name that should not be formatted",
+    "--skip-keyword-call", type=str, multiple=True, help="Keyword call name that should not be formatted"
 )
 keyword_call_pattern_option = click.option(
     "--skip-keyword-call-pattern",
@@ -167,40 +163,17 @@ keyword_call_pattern_option = click.option(
     help="Keyword call name pattern that should not be formatted",
 )
 settings_option = click.option("--skip-settings", is_flag=True, help="Skip formatting of settings")
-arguments_option = click.option(
-    "--skip-arguments",
-    is_flag=True,
-    help="Skip formatting of arguments",
-)
-setup_option = click.option(
-    "--skip-setup",
-    is_flag=True,
-    help="Skip formatting of setup",
-)
-teardown_option = click.option(
-    "--skip-teardown",
-    is_flag=True,
-    help="Skip formatting of teardown",
-)
-timeout_option = click.option(
-    "--skip-timeout",
-    is_flag=True,
-    help="Skip formatting of timeout",
-)
-template_option = click.option(
-    "--skip-template",
-    is_flag=True,
-    help="Skip formatting of template",
-)
-return_option = click.option(
-    "--skip-return",
-    is_flag=True,
-    help="Skip formatting of return statement",
-)
-tags_option = click.option(
-    "--skip-tags",
-    is_flag=True,
-    help="Skip formatting of tags",
+arguments_option = click.option("--skip-arguments", is_flag=True, help="Skip formatting of arguments")
+setup_option = click.option("--skip-setup", is_flag=True, help="Skip formatting of setup")
+teardown_option = click.option("--skip-teardown", is_flag=True, help="Skip formatting of teardown")
+timeout_option = click.option("--skip-timeout", is_flag=True, help="Skip formatting of timeout")
+template_option = click.option("--skip-template", is_flag=True, help="Skip formatting of template")
+return_option = click.option("--skip-return", is_flag=True, help="Skip formatting of return statement")
+tags_option = click.option("--skip-tags", is_flag=True, help="Skip formatting of tags")
+sections_option = click.option(
+    "--skip-sections",
+    type=str,
+    help="Skip formatting of sections. Provide multiple sections with comma separated value",
 )
 comments_option = click.option("--skip-comments", is_flag=True, help="Skip formatting of comments")
 block_comments_option = click.option("--skip-block-comments", is_flag=True, help="Skip formatting of block comments")
